RegisterBlock

Struct RegisterBlock 

#[repr(C)]
pub struct RegisterBlock {
Show 27 fields pub gpio_intr: Reg<GPIO_INTR_SPEC>, pub gpio_intr_raw: Reg<GPIO_INTR_RAW_SPEC>, pub gpio_intr_type: Reg<GPIO_INTR_TYPE_SPEC>, pub gpio_intr_pol: Reg<GPIO_INTR_POL_SPEC>, pub gpio_intr_en_ap: Reg<GPIO_INTR_EN_AP_SPEC>, pub gpio_intr_en_m4: Reg<GPIO_INTR_EN_M4_SPEC>, pub gpio_intr_en_ffe0: Reg<GPIO_INTR_EN_FFE0_SPEC>, pub gpio_intr_en_ffe1: Reg<GPIO_INTR_EN_FFE1_SPEC>, pub other_intr: Reg<OTHER_INTR_SPEC>, pub other_intr_en_ap: Reg<OTHER_INTR_EN_AP_SPEC>, pub other_intr_en_m4: Reg<OTHER_INTR_EN_M4_SPEC>, pub software_intr_1: Reg<SOFTWARE_INTR_1_SPEC>, pub software_intr_1_en_ap: Reg<SOFTWARE_INTR_1_EN_AP_SPEC>, pub software_intr_2: Reg<SOFTWARE_INTR_2_SPEC>, pub software_intr_2_en_ap: Reg<SOFTWARE_INTR_2_EN_AP_SPEC>, pub software_intr_en_m4: Reg<SOFTWARE_INTR_EN_M4_SPEC>, pub ffe_intr: Reg<FFE_INTR_SPEC>, pub ffe_intr_en_ap: Reg<FFE_INTR_EN_AP_SPEC>, pub ffe_intr_en_m4: Reg<FFE_INTR_EN_M4_SPEC>, pub fb_intr: Reg<FB_INTR_SPEC>, pub fb_intr_raw: Reg<FB_INTR_RAW_SPEC>, pub fb_intr_type: Reg<FB_INTR_TYPE_SPEC>, pub fb_intr_pol: Reg<FB_INTR_POL_SPEC>, pub fb_intr_en_ap: Reg<FB_INTR_EN_AP_SPEC>, pub fb_intr_en_m4: Reg<FB_INTR_EN_M4_SPEC>, pub m4_mem_aon_intr: Reg<M4_MEM_AON_INTR_SPEC>, pub m4_mem_aon_intr_en: Reg<M4_MEM_AON_INTR_EN_SPEC>, /* private fields */
}
Register block

Fields

gpio_intr: Reg<GPIO_INTR_SPEC>

0x00 - Indicators of interrupt triggers detected

gpio_intr_raw: Reg<GPIO_INTR_RAW_SPEC>

0x04 - GPIO raw interrupt indicators

gpio_intr_type: Reg<GPIO_INTR_TYPE_SPEC>

0x08 - Indicators of interrupt trigger types

gpio_intr_pol: Reg<GPIO_INTR_POL_SPEC>

0x0c - Indicators of interrupt trigger polarities (will depend on the type of interrupt)

gpio_intr_en_ap: Reg<GPIO_INTR_EN_AP_SPEC>

0x10 - GPIO interrupt enable for AP

gpio_intr_en_m4: Reg<GPIO_INTR_EN_M4_SPEC>

0x14 - GPIO interrupt enable for M4

gpio_intr_en_ffe0: Reg<GPIO_INTR_EN_FFE0_SPEC>

0x18 - GPIO interrupt enable for FFE0

gpio_intr_en_ffe1: Reg<GPIO_INTR_EN_FFE1_SPEC>

0x1c - GPIO interrupt enable for FFE1

other_intr: Reg<OTHER_INTR_SPEC>

0x30 - Indicators of interrupt triggers detected

other_intr_en_ap: Reg<OTHER_INTR_EN_AP_SPEC>

0x34 - Various interrupt enable for AP

other_intr_en_m4: Reg<OTHER_INTR_EN_M4_SPEC>

0x38 - Various interrupt enable for M4

software_intr_1: Reg<SOFTWARE_INTR_1_SPEC>

0x40 - Indicators of General purpose software interrupt 1 triggers detected

software_intr_1_en_ap: Reg<SOFTWARE_INTR_1_EN_AP_SPEC>

0x44 - General purpose Software interrupt 1 enable for AP

software_intr_2: Reg<SOFTWARE_INTR_2_SPEC>

0x50 - Indicators of General purpose software interrupt 2 triggers detected

software_intr_2_en_ap: Reg<SOFTWARE_INTR_2_EN_AP_SPEC>

0x54 - General purpose Software interrupt 2 enable for AP

software_intr_en_m4: Reg<SOFTWARE_INTR_EN_M4_SPEC>

0x58 - General purpose Software interrupt 2 enable for M4

ffe_intr: Reg<FFE_INTR_SPEC>

0x60 - Indicators of FFE0 interrupt triggers detected

ffe_intr_en_ap: Reg<FFE_INTR_EN_AP_SPEC>

0x64 - FFE0 interrupt enable for AP

ffe_intr_en_m4: Reg<FFE_INTR_EN_M4_SPEC>

0x68 - FFE0 interrupt enable for M4

fb_intr: Reg<FB_INTR_SPEC>

0x80 - Indicators of interrupt triggers detected

fb_intr_raw: Reg<FB_INTR_RAW_SPEC>

0x84 - FB raw interrupt indicators

fb_intr_type: Reg<FB_INTR_TYPE_SPEC>

0x88 - Indicators of interrupt trigger types

fb_intr_pol: Reg<FB_INTR_POL_SPEC>

0x8c - Indicators of interrupt trigger polarities (will depend on the type of interrupt)

fb_intr_en_ap: Reg<FB_INTR_EN_AP_SPEC>

0x90 - FB interrupt enable for AP

fb_intr_en_m4: Reg<FB_INTR_EN_M4_SPEC>

0x94 - FB interrupt enable for M4

m4_mem_aon_intr: Reg<M4_MEM_AON_INTR_SPEC>

0xa0 - Indicator of detected SRAM access while shut down or sleep mode interrupts

m4_mem_aon_intr_en: Reg<M4_MEM_AON_INTR_EN_SPEC>

0xa4 - Interrupt enable for SRAM access while in shut down or deep sleep modes