pub struct OUT2_W<'a> { /* private fields */ }Expand description
Field Out2 writer - This bit is the complement of the UART Out2 (nUARTOut2) modem status output. That is, when the bit is programmed to a 1, the output is 0. For DTE this can be used as Ring Indicator (RI).
Implementations