pub struct FE_R(/* private fields */);Expand description
Field FE reader - Framing error. When set to 1, it indicates that the received character did not have a valid stop bit (a valid stop bit is 1). In FIFO mode, this error is associated with the character at the top of the FIFO.
Methods from Deref<Target = FieldReader<bool, bool>>