#[repr(C)]pub struct RegisterBlock {
pub dma_dest_addr: Reg<DMA_DEST_ADDR_SPEC>,
pub dma_xfer_cnt: Reg<DMA_XFER_CNT_SPEC>,
pub cfg_flash_header: Reg<CFG_FLASH_HEADER_SPEC>,
pub dma_intr: Reg<DMA_INTR_SPEC>,
pub dma_intr_mask: Reg<DMA_INTR_MASK_SPEC>,
/* private fields */
}Expand description
Register block
Fields
dma_dest_addr: Reg<DMA_DEST_ADDR_SPEC>0x04 - DMA destination address : this register is only accessable when the dma or cfg_sm is not selecting the dmas_mux.
dma_xfer_cnt: Reg<DMA_XFER_CNT_SPEC>0x08 - DMA transfer count in frames (8 bit) (minus 1) : this register is only accessable when the dma or cfg_sm is not selecting the dmas_mux.
cfg_flash_header: Reg<CFG_FLASH_HEADER_SPEC>0x0c - Header values read from EEPROM : this register is only accessable when the dma or cfg_sm is not selecting the dmas_mux.
dma_intr: Reg<DMA_INTR_SPEC>0x10 - DMA interrupts
dma_intr_mask: Reg<DMA_INTR_MASK_SPEC>0x14 - DMA interrupt mask
Implementations
Sourceimpl RegisterBlock
impl RegisterBlock
Sourcepub fn cfg_machine_st_delay(&self) -> &Reg<CFG_MACHINE_ST_DELAY_SPEC>
pub fn cfg_machine_st_delay(&self) -> &Reg<CFG_MACHINE_ST_DELAY_SPEC>
0x00 - This is the delay value used in the config state machine. It is used for both deep sleep wakeup delay and between retries.
Sourcepub fn dma_ctrl(&self) -> &Reg<DMA_CTRL_SPEC>
pub fn dma_ctrl(&self) -> &Reg<DMA_CTRL_SPEC>
0x00 - DMA Control : this register is only accessable when the dma or cfg_sm is not selecting the dmas_mux.