#[repr(C)]pub struct RegisterBlock {
pub dma_req: Reg<DMA_REQ_SPEC>,
pub dma_waitonreq_reg: Reg<DMA_WAITONREQ_REG_SPEC>,
pub dma_active_reg: Reg<DMA_ACTIVE_REG_SPEC>,
pub sdma_pwrd_cnt: Reg<SDMA_PWRD_CNT_SPEC>,
pub sdma_sram_ctl: Reg<SDMA_SRAM_CTL_SPEC>,
}Expand description
Register block
Fields
dma_req: Reg<DMA_REQ_SPEC>0x00 - DMA request
dma_waitonreq_reg: Reg<DMA_WAITONREQ_REG_SPEC>0x04 - DMA wait on request register
dma_active_reg: Reg<DMA_ACTIVE_REG_SPEC>0x08 - dma_active signal status from System DMA
sdma_pwrd_cnt: Reg<SDMA_PWRD_CNT_SPEC>0x0c - sdma power down event threshold. If sdma stays in idle cycles longer than the threshold, sdma will be automaticlly put into power down to save power.
sdma_sram_ctl: Reg<SDMA_SRAM_CTL_SPEC>0x10 - Control register for System DMA SRAM